pub struct Route {
pub from: Vec<String>,
pub join: Option<Join>,
pub timeout_sec: Option<i64>,
pub to: Vec<String>,
}Expand description
One entry of the route map, possibly expanding to several edges.
Fields
from: Vec<String>Sending agents.
join: Option<Join>Set when flights on this edge are parked at a rendezvous barrier.
timeout_sec: Option<i64>Backstop for a barrier that never completes.
to: Vec<String>Receiving agents.